@@ -1,18 +1,12 @@
 import abc
 from typing import Any
 
-from annet.annlib.netdev.views.hardware import HardwareView, hw_to_vendor
-
+from annet.annlib.netdev.views.hardware import HardwareView
+from annet.vendors import registry_connector
 from annet.connectors import Connector
 
 
-try:
-    from annet.annlib.netdev.views.hardware import vendor_to_hw
-except ImportError:
-    from netdev.views.hardware import vendor_to_hw
-
-
-class _HardwareConnector(Connector["HarwareProvider"]):
+class _HardwareConnector(Connector["HardwareProvider"]):
     name = "Hardware"
     ep_name = "hardware"
     ep_by_group_only = "annet.connectors.hardware"
@@ -21,7 +15,7 @@ class _HardwareConnector(Connector["HarwareProvider"]):
 hardware_connector = _HardwareConnector()
 
 
-class HarwareProvider(abc.ABC):
+class HardwareProvider(abc.ABC):
     @abc.abstractmethod
     def make_hw(self, hw_model: str, sw_version: str) -> Any:
         pass
@@ -31,16 +25,18 @@ class HarwareProvider(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def hw_to_vendor(self, hw: Any) -> str:
+    def hw_to_vendor(self, hw: Any) -> str | None:
         pass
 
 
-class AnnetHardwareProvider(HarwareProvider):
+class AnnetHardwareProvider(HardwareProvider):
     def make_hw(self, hw_model: str, sw_version: str) -> HardwareView:
         return HardwareView(hw_model, sw_version)
 
     def vendor_to_hw(self, vendor: str) -> HardwareView:
-        return vendor_to_hw(vendor)
+        return registry_connector.get().get(vendor.lower()).hardware
 
-    def hw_to_vendor(self, hw: HardwareView) -> str:
-        return hw_to_vendor(hw)
+    def hw_to_vendor(self, hw: HardwareView) -> str | None:
+        if vendor := registry_connector.get().match(hw, None):
+            return vendor.NAME
+        return None
