@@ -14,7 +14,7 @@ class H3CVendor(AbstractVendor):
 
         before.add_cmd(Command("system-view"))
         if do_finalize:
-            after.add_cmd(Command("save force", timeout=90))
+            after.add_cmd(Command("save force", timeout=90, read_timeout=90))
 
         return before, after
 
